﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace C1Tdbg_CellButton_CheckBoxResize_CS
{
    public partial class Form1 : Form
    {
        private Image onImage = Image.FromFile(@"..\\..\\checkon.png");
        private Image offImage = Image.FromFile(@"..\\..\\checkoff.png");
        private CustomEditor editor;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            #region "Create data"
            List<Persons> name = new List<Persons>();
            name.Add(new Persons
            {
                Name = "Robert Ludlum",
                ID = 1,
                Present = true
            });
            name.Add(new Persons
            {
                Name = "John Smith",
                ID = 2,
                Present = false
            });
            name.Add(new Persons
            {
                Name = "Frederick Forsyth",
                ID = 3,
                Present = true
            });
            name.Add(new Persons
            {
                Name = "Dan Brown",
                ID = 4,
                Present = false
            });
            name.Add(new Persons
            {
                Name = "Tom Clancy",
                ID = 5,
                Present = true
            });
            #endregion

            // TrueDBGrid's settings
            C1TrueDBGrid1.DataSource = name;
            C1TrueDBGrid1.SpringMode = true;

            // Settings of ID column (Dropdown)
            C1.Win.C1TrueDBGrid.ValueItems items = this.C1TrueDBGrid1.Columns["ID"].ValueItems;
            items.Translate = true;
            items.Values.Add(new C1.Win.C1TrueDBGrid.ValueItem("1", "A"));
            items.Values.Add(new C1.Win.C1TrueDBGrid.ValueItem("2", "B"));
            items.Values.Add(new C1.Win.C1TrueDBGrid.ValueItem("3", "C"));
            items.Values.Add(new C1.Win.C1TrueDBGrid.ValueItem("4", "D"));
            items.Values.Add(new C1.Win.C1TrueDBGrid.ValueItem("5", "E"));

            // Populate and set custom editor for column "ID"
            editor = new CustomEditor();
            editor.Items.Add(new CustomItem(1, "A"));
            editor.Items.Add(new CustomItem(2, "B"));
            editor.Items.Add(new CustomItem(3, "C"));
            editor.Items.Add(new CustomItem(4, "D"));
            editor.Items.Add(new CustomItem(5, "E"));
            C1TrueDBGrid1.Columns["ID"].Editor = editor;

            // Set Column appearance
            C1TrueDBGrid1.Splits[0].DisplayColumns["ID"].HeadingStyle.HorizontalAlignment 
                = C1.Win.C1TrueDBGrid.AlignHorzEnum.Near;
            C1TrueDBGrid1.Splits[0].DisplayColumns["ID"].Style.HorizontalAlignment 
                = C1.Win.C1TrueDBGrid.AlignHorzEnum.Near;
            C1TrueDBGrid1.Splits[0].DisplayColumns["ID"].Width = 80;
            C1TrueDBGrid1.RowHeight = editor.PreferredHeight;

            // Settings of Test column (Checkbox)
            C1TrueDBGrid1.Splits[0].DisplayColumns["Present"].Locked = true;
            C1TrueDBGrid1.Splits[0].DisplayColumns["Present"].OwnerDraw = true;
            C1TrueDBGrid1.Splits[0].DisplayColumns["Present"].Width = 80;

            C1TrueDBGrid1.RowHeight = editor.PreferredHeight - 1;
        }

        #region "Events"
        private void c1SizerLight1_ResizingFont(object sender, C1.Win.C1Sizer.C1SizerLightEventArgs e)
        {
            // Adjust RowHeight and Font            
            if (e.Control.Name == this.C1TrueDBGrid1.Name)
            {
                C1TrueDBGrid1.Splits[0].HeadingStyle.Font = C1TrueDBGrid1.Font;
                C1TrueDBGrid1.Splits[0].Style.Font = C1TrueDBGrid1.Font;
                editor.Font = C1TrueDBGrid1.Font;
                C1TrueDBGrid1.RowHeight = editor.PreferredHeight - 1;
            }
        }

        private void C1TrueDBGrid1_Click(object sender, EventArgs e)
        {
            // Toggle checkbox's checked state
            int row = 0;
            int col = 0;
            Point pos = C1TrueDBGrid1.PointToClient(Control.MousePosition);
            C1TrueDBGrid1.CellContaining(pos.X, pos.Y, out row, out col);
            if (col > -1 && C1TrueDBGrid1.Splits[0].DisplayColumns[col].Name == "Present")
            {
                if (Convert.ToBoolean(C1TrueDBGrid1[row, col]))
                    C1TrueDBGrid1[row, col] = false;
                else if (!Convert.ToBoolean(C1TrueDBGrid1[row, col]))
                    C1TrueDBGrid1[row, col] = true;
            }
        }

        private void C1TrueDBGrid1_OwnerDrawCell(object sender, C1.Win.C1TrueDBGrid.OwnerDrawCellEventArgs e)
        {
            // Draw checkbox            
            if (e.Column.Name == "Present")
            {
                e.Handled = true;
                Rectangle rect = e.CellRect;
                e.Graphics.FillRectangle(Brushes.White, rect);
                Point pos = new Point(rect.Left + (rect.Width - rect.Height) / 2, rect.Top);
                if (e.Text == "True")
                {
                    e.Graphics.DrawImage(onImage, new Rectangle(pos, new Size(rect.Height, rect.Height - 2)));
                }
                else if (e.Text == "False")
                {
                    e.Graphics.DrawImage(offImage, new Rectangle(pos, new Size(rect.Height, rect.Height - 2)));
                }
            }
        }
        #endregion 
    }
    /// <summary>
    /// Combo-box editor type
    /// </summary>
    public class CustomEditor : ComboBox, C1.Win.C1FlexGrid.IC1EmbeddedEditor
    {
        public string C1EditorFormat(object value, string mask)
        {
            return string.Concat(value);
        }

        public System.Drawing.Design.UITypeEditorEditStyle C1EditorGetStyle()
        {
            return System.Drawing.Design.UITypeEditorEditStyle.None;
        }

        public object C1EditorGetValue()
        {
            return ((CustomItem)this.SelectedItem).Key;
        }

        public void C1EditorInitialize(object value, System.Collections.IDictionary editorAttributes)
        {
            foreach (CustomItem item in this.Items)
            {
                if (item.Key == Convert.ToInt32(value))
                {
                    this.SelectedItem = item;
                    return;
                }
            }
        }

        public bool C1EditorKeyDownFinishEdit(System.Windows.Forms.KeyEventArgs e)
        {
            return false;
        }

        public void C1EditorUpdateBounds(System.Drawing.Rectangle rc)
        {
            base.Location = rc.Location;
            base.Size = rc.Size;
        }

        public bool C1EditorValueIsValid()
        {
            return true;
        }
    }

    /// <summary>
    /// For grid data
    /// </summary>
    public class Persons
    {
        public string Name { get; set; }
        public int ID { get; set; }
        public bool Present { get; set; }
    }

    /// <summary>
    /// For combo-box list
    /// </summary>
    public class CustomItem
    {
        public int Key { get; set; }
        public string Value { get; set; }
        public CustomItem(int key, string value)
        {
            this.Key = key;
            this.Value = value;
        }
        public override string ToString()
        {
            return this.Value;
        }
    }
}
